@@ -3,6 +3,10 @@ from datetime import datetime
 from typing import Any, Dict, Optional
 
 import arrow
+from loguru import logger
+
+from snatch.base.status import IntegrationStatus
+from snatch.helpers.validator import Validator
 
 
 @dataclass
@@ -33,7 +37,7 @@ class BaseData:
     """
 
     tax_id: Optional[str] = None
-    integration_status: Optional[str] = None
+    integration_status: Optional[IntegrationStatus] = None
     status_reason: str = ""
     prospect_date: Optional[datetime] = None
     payload: Optional[Dict[str, Any]] = None
@@ -46,9 +50,7 @@ class BaseData:
         """Return DataSource Object Name."""
         return self.__class__.__name__
 
-    def find_current_status(
-        self, max_days_old: Optional[int], max_periods_old: Optional[int]
-    ):
+    def find_current_status(self, data):
         """Find current Status for Data.
 
         Current available status:
@@ -69,26 +71,44 @@ class BaseData:
         :param max_days_old: Max days old for current data, for check expiration.
         :param max_periods_old: Max months old for current data, for check expiration.
         """
-        if self.integration_status in ["SUCCESS", "INCOMPLETE", "NO_DATA"]:
+        if self.integration_status.is_success:
             days_old = (
                 arrow.utcnow().ceil("day") - arrow.get(self.prospect_date).floor("day")
             ).days
-            months_old = days_old / 30
-            expired_by_date = max_days_old is not None and days_old > max_days_old
+            months_old = int(
+                (
+                    arrow.utcnow().ceil("month")
+                    - arrow.get(self.prospect_date).floor("day")
+                ).days
+                / 30
+            )
+            expired_by_date = (
+                data["max_days_old"] is not None
+                and days_old > data["max_days_old"]
+                or data["max_days_old"] == 0
+            )
             expired_by_period = (
-                max_periods_old is not None and months_old > max_periods_old
+                data["max_periods_old"] is not None
+                and months_old > data["max_periods_old"]
             )
             self.integration_status = (
-                "EXPIRED"
-                if expired_by_date or expired_by_period
+                IntegrationStatus.EXPIRED
+                if expired_by_date is True
+                or expired_by_period is True
+                or Validator(data).start() is False
                 else self.integration_status
             )
-            if expired_by_period or expired_by_period:
-                self.integration_status = "EXPIRED"
-                self.status_reason = (
-                    f"Expired by Date: {days_old} old"
-                    if expired_by_date
-                    else f"Expired by Period: {months_old} months old"
+            if self.integration_status == IntegrationStatus.EXPIRED:
+                status_reason = (
+                    "Data from Datasource is: "
+                    + (
+                        f"Expired by Date: {days_old} old"
+                        if expired_by_date
+                        else f"Expired by Period: {months_old} months old"
+                    )
+                    + ". Requesting new prospect..."
                 )
-        if self.integration_status in ["PENDING", "RUNNING"]:
-            self.integration_status = "WAITING"
+                logger.warning(status_reason)
+                self.status_reason = status_reason
+        if self.integration_status.need_wait:
+            self.integration_status = IntegrationStatus.WAITING
