@@ -38,6 +38,7 @@ class BaseSnatch:
     * default_max_periods (int)     Max number of periods for expiration check.
                                     All prospections with prospect month older than
                                     default_max_periods will be marked as EXPIRED.
+    * default_period (int)          Default period for prospect.
     * use_env                       Use specific environment. Default: `production`.
     * use_log                       Use specific Log Level for this DataSource.
                                     Default: `INFO`. Can override with
@@ -52,6 +53,7 @@ class BaseSnatch:
     base_url_key: Optional[str] = None
     settings: Optional[Cut] = None
     default_max_periods: Optional[int] = None
+    default_period: Optional[int] = arrow.utcnow().shift(months=-2).floor("month")
     use_env: Optional[str] = None
     use_log: str = "INFO"
 
@@ -95,7 +97,7 @@ class BaseSnatch:
                 next_check = arrow.utcnow().shift(seconds=shift_seconds)
                 data = self._last_prospect(timeout=timeout)
                 if data and data.integration_status.is_final:
-                    logger.debug(
+                    logger.info(
                         f"Data Received - Status is: {data.integration_status.value}"
                     )
                     return data
@@ -104,13 +106,16 @@ class BaseSnatch:
 
     def _post_new_prospect(self, timeout: int) -> BaseData:
         url = "/api/prospects/from_tax_id/"
-        payload = {"tax_id": self.tax_id}
+        payload = {
+            "tax_id": self.tax_id,
+            "period": self.default_period.format("YYYYMM"),
+        }
         data = self._request_and_create_data(url=url, timeout=timeout, payload=payload)
         return data
 
     def _last_prospect(self, timeout: int) -> BaseData:
         url = f"/api/companies/{self.tax_id}/last_prospect/"
-        logger.debug(f"Calling {url}...")
+        logger.info(f"Calling {url}...")
         return self._request_and_create_data(url=url, timeout=timeout)
 
     def _last_valid(self, timeout: int) -> BaseData:
@@ -168,7 +173,7 @@ class BaseSnatch:
         try:
             method = "POST" if payload else "GET"
             full_url = f"{self.base_url}{url}"
-            logger.debug(f"Start {method} request to {full_url} ...")
+            logger.info(f"Start {method} request to {full_url} ...")
             response = requests.request(
                 method=method,
                 url=full_url,
@@ -176,7 +181,7 @@ class BaseSnatch:
                 headers=self.headers,
                 timeout=timeout,
             )
-            logger.debug(f"Response status code is: {response.status_code}")
+            logger.info(f"Response status code is: {response.status_code}")
             response.raise_for_status()
             return self._format_response(response.json())
         except HTTPError as error:
@@ -215,6 +220,7 @@ class BaseSnatch:
         timeout: Optional[int] = None,
         max_days_old: Optional[int] = None,
         max_periods_old: Optional[int] = None,
+        period: Optional[int] = None,
     ):
         """Get or Request DataSource Integration Data.
 
@@ -239,8 +245,11 @@ class BaseSnatch:
         :param max_periods_old: Max Months old for last integration,
                                 if exists.
         :param timeout: Time in seconds before timeout connection.
+        :param period: Specific base date for prospecting.
         :return: DataSource Data Object
         """
+        suffix = []
+        status_validator = {}
         self.tax_id = tax_id
         cnpj = CNPJ()
         cpf = CPF()
@@ -257,10 +266,24 @@ class BaseSnatch:
         if max_periods_old is None:
             max_periods_old = self.default_max_periods
 
+        if period:
+            date = arrow.get(
+                f"{period}01"
+            )  # On error will raise arrow.parse.ParseError
+            if date >= self.default_period:
+                raise ValueError("Invalid Date")
+            self.default_period = date
         data = self._last_prospect(timeout=timeout)
-        data.find_current_status(
-            max_days_old=max_days_old, max_periods_old=max_periods_old
-        )
+
+        status_validator["max_days_old"] = max_days_old
+        status_validator["max_periods_old"] = max_periods_old
+        status_validator["data"] = data.__dict__
+        status_validator["class"] = str(self.__module__).strip("snatch.")
+        for item in self.extends:
+            suffix.append(item.value)
+        status_validator["dataset"] = suffix
+
+        data.find_current_status(status_validator)
 
         # Check Status
         if data.integration_status.is_final:
