@@ -76,12 +76,12 @@ class DataRiskSerializer(BaseSchema):
 
     @pre_load
     def log_received_data(self, data, **kwargs) -> Dict[Any, Any]:
-        logger.debug(f"Request Data received is: {data}")
+        logger.info(f"Request Data received is: {data}")
         return data
 
     @post_load
     def make_data(self, data, **kwargs) -> DataRiskData:
-        logger.debug(f"Deserialized Data received is: {data}")
+        logger.info(f"Deserialized Data received is: {data}")
         new_data = DataRiskData(**data)
         new_data.datasource_base_url = DataRisk.base_url
         return new_data
