@@ -41,12 +41,12 @@ class FGTSSerializer(BaseSchema):
 
     @pre_load
     def log_received_data(self, data, **kwargs) -> Dict[Any, Any]:
-        logger.debug(f"Request Data received is: {data}")
+        logger.info(f"Request Data received is: {data}")
         return data
 
     @post_load
     def make_data(self, data, **kwargs) -> FGTSData:
-        logger.debug(f"Deserialized Data received is: {data}")
+        logger.info(f"Deserialized Data received is: {data}")
         new_data = FGTSData(**data)
         new_data.datasource_base_url = FGTS.base_url
         return new_data
